.. _install_req:

Requirements
============

HydraTK is implemented in Python. Before you can install, you must fulfill basic requirements.

* Any OS Unix - distributions Debian, Red Hat, etc. with apt-get or yum package manager
* Python interpreter - versions 2.6.x, 2.7.x, 3.3.x, 3.4.x, 3.5.x
* Python modules - setuptools, pip, wheel

.. note::

   OS Windows and OS X are not supported, but there are future plans to support them.